-file("/usr/local/lib/erlang/lib/parsetools-2.1.1/include/leexinc.hrl", 0).
%% The source of this file is part of leex distribution, as such it
%% has the same Copyright as the other files in the leex
%% distribution. The Copyright is defined in the accompanying file
%% COPYRIGHT. However, the resultant scanner generated by leex is the
%% property of the creator of the scanner and is not covered by that
%% Copyright.

-module(lfe_scan).

-export([string/1,string/2,token/2,token/3,tokens/2,tokens/3]).
-export([format_error/1]).

%% User code. This is placed here to allow extra attributes.
-file("src/lfe_scan.xrl", 92).
%% Copyright (c) 2008-2013 Robert Virding
%%
%% Licensed under the Apache License, Version 2.0 (the "License");
%% you may not use this file except in compliance with the License.
%% You may obtain a copy of the License at
%%
%%     http://www.apache.org/licenses/LICENSE-2.0
%%
%% Unless required by applicable law or agreed to in writing, software
%% distributed under the License is distributed on an "AS IS" BASIS,
%% WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
%% See the License for the specific language governing permissions and
%% limitations under the License.

%% File    : lfe_scan.erl
%% Author  : Robert Virding
%% Purpose : Token definitions for Lisp Flavoured Erlang.

-import(string, [substr/2,substr/3]).

%% symbol_token(Chars, Line) -> {token,{symbol,Line,Symbol}} | {error,E}.
%% Build a symbol from list of legal characters, else error.

symbol_token(Cs, L) ->
    case catch {ok,list_to_atom(Cs)} of
    {ok,S} -> {token,{symbol,L,S}};
    _ -> {error,"illegal symbol"}
    end.

%% base_token(Chars, Base, Line) -> Integer.
%% Convert a string of Base characters into a number. We know that
%% the strings only contain the correct character.

base_token(Cs, B, L) ->
    case base1(Cs, B, 0) of
    {N,[]} -> {token,{number,L,N}};
    {_,_} -> {error,"illegal based number"}
    end.

base1([C|Cs], Base, SoFar) when C >= $0, C =< $9, C < Base + $0 ->
    Next = SoFar * Base + (C - $0),
    base1(Cs, Base, Next);
base1([C|Cs], Base, SoFar) when C >= $a, C =< $z, C < Base + $a - 10 ->
    Next = SoFar * Base + (C - $a + 10),
    base1(Cs, Base, Next);

base1([C|Cs], Base, SoFar) when C >= $A, C =< $Z, C < Base + $A - 10 ->
    Next = SoFar * Base + (C - $A + 10),
    base1(Cs, Base, Next);
base1([C|Cs], _Base, SoFar) -> {SoFar,[C|Cs]};
base1([], _Base, N) -> {N,[]}.

%% char_token(InputChars, Line) -> {token,{number,L,N}} | {error,E}.
%% Convert an input string into the corresponding character. We know
%% that the input string is correct.

char_token([$x,C|Cs], L) ->
    case base1([C|Cs], 16, 0) of
    {N,[]} -> {token,{number,L,N}};
    _ -> {error,"illegal character"}
    end;
char_token([C], L) -> {token,{number,L,C}}.

%% chars(InputChars) -> Chars.
%% Convert an input string into the corresponding string
%% characters. We know that the input string is correct.

chars([$\\,$x,C|Cs0]) ->
    case hex_char(C) of
    true ->
        case base1([C|Cs0], 16, 0) of
        {N,[$;|Cs1]} -> [N|chars(Cs1)];
        _Other -> [escape_char($x)|chars([C|Cs0])]
        end;
    false -> [escape_char($x)|chars([C|Cs0])]
    end;
chars([$\\,C|Cs]) -> [escape_char(C)|chars(Cs)];
chars([C|Cs]) -> [C|chars(Cs)];
chars([]) -> [].

%% Block Comment:
%% Provide a sensible error when people attempt to include nested
%% comments because currently the parser cannot process them without
%% a rebuild. But simply exploding on a '#|' is not going to be
%% that helpful.
block_comment(TokenChars) ->
  %% Check we're not opening another comment block.
  case string:str(TokenChars, "#|") of
    0 -> skip_token; %% No nesting found
    _ -> {error, "illegal nested block comment"}
  end.

hex_char(C) when C >= $0, C =< $9 -> true;
hex_char(C) when C >= $a, C =< $f -> true;
hex_char(C) when C >= $A, C =< $F -> true;
hex_char(_) -> false.

escape_char($n) -> $\n;                %\n = LF
escape_char($r) -> $\r;                %\r = CR
escape_char($t) -> $\t;                %\t = TAB
escape_char($v) -> $\v;                %\v = VT
escape_char($b) -> $\b;                %\b = BS
escape_char($f) -> $\f;                %\f = FF
escape_char($e) -> $\e;                %\e = ESC
escape_char($s) -> $\s;                %\s = SPC
escape_char($d) -> $\d;                %\d = DEL
escape_char(C) -> C.

-file("/usr/local/lib/erlang/lib/parsetools-2.1.1/include/leexinc.hrl", 14).

format_error({illegal,S}) -> ["illegal characters ",io_lib:write_string(S)];
format_error({user,S}) -> S.

string(String) -> string(String, 1).

string(String, Line) -> string(String, Line, String, []).

%% string(InChars, Line, TokenChars, Tokens) ->
%% {ok,Tokens,Line} | {error,ErrorInfo,Line}.
%% Note the line number going into yystate, L0, is line of token
%% start while line number returned is line of token end. We want line
%% of token start.

string([], L, [], Ts) ->                     % No partial tokens!
    {ok,yyrev(Ts),L};
string(Ics0, L0, Tcs, Ts) ->
    case yystate(yystate(), Ics0, L0, 0, reject, 0) of
        {A,Alen,Ics1,L1} ->                  % Accepting end state
            string_cont(Ics1, L1, yyaction(A, Alen, Tcs, L0), Ts);
        {A,Alen,Ics1,L1,_S1} ->              % Accepting transistion state
            string_cont(Ics1, L1, yyaction(A, Alen, Tcs, L0), Ts);
        {reject,_Alen,Tlen,_Ics1,L1,_S1} ->  % After a non-accepting state
            {error,{L0,?MODULE,{illegal,yypre(Tcs, Tlen+1)}},L1};
        {A,Alen,_Tlen,_Ics1,_L1,_S1} ->
            string_cont(yysuf(Tcs, Alen), L0, yyaction(A, Alen, Tcs, L0), Ts)
    end.

%% string_cont(RestChars, Line, Token, Tokens)
%% Test for and remove the end token wrapper. Push back characters
%% are prepended to RestChars.

-dialyzer({nowarn_function, string_cont/4}).

string_cont(Rest, Line, {token,T}, Ts) ->
    string(Rest, Line, Rest, [T|Ts]);
string_cont(Rest, Line, {token,T,Push}, Ts) ->
    NewRest = Push ++ Rest,
    string(NewRest, Line, NewRest, [T|Ts]);
string_cont(Rest, Line, {end_token,T}, Ts) ->
    string(Rest, Line, Rest, [T|Ts]);
string_cont(Rest, Line, {end_token,T,Push}, Ts) ->
    NewRest = Push ++ Rest,
    string(NewRest, Line, NewRest, [T|Ts]);
string_cont(Rest, Line, skip_token, Ts) ->
    string(Rest, Line, Rest, Ts);
string_cont(Rest, Line, {skip_token,Push}, Ts) ->
    NewRest = Push ++ Rest,
    string(NewRest, Line, NewRest, Ts);
string_cont(_Rest, Line, {error,S}, _Ts) ->
    {error,{Line,?MODULE,{user,S}},Line}.

%% token(Continuation, Chars) ->
%% token(Continuation, Chars, Line) ->
%% {more,Continuation} | {done,ReturnVal,RestChars}.
%% Must be careful when re-entering to append the latest characters to the
%% after characters in an accept. The continuation is:
%% {token,State,CurrLine,TokenChars,TokenLen,TokenLine,AccAction,AccLen}

token(Cont, Chars) -> token(Cont, Chars, 1).

token([], Chars, Line) ->
    token(yystate(), Chars, Line, Chars, 0, Line, reject, 0);
token({token,State,Line,Tcs,Tlen,Tline,Action,Alen}, Chars, _) ->
    token(State, Chars, Line, Tcs ++ Chars, Tlen, Tline, Action, Alen).

%% token(State, InChars, Line, TokenChars, TokenLen, TokenLine,
%% AcceptAction, AcceptLen) ->
%% {more,Continuation} | {done,ReturnVal,RestChars}.
%% The argument order is chosen to be more efficient.

token(S0, Ics0, L0, Tcs, Tlen0, Tline, A0, Alen0) ->
    case yystate(S0, Ics0, L0, Tlen0, A0, Alen0) of
        %% Accepting end state, we have a token.
        {A1,Alen1,Ics1,L1} ->
            token_cont(Ics1, L1, yyaction(A1, Alen1, Tcs, Tline));
        %% Accepting transition state, can take more chars.
        {A1,Alen1,[],L1,S1} ->                  % Need more chars to check
            {more,{token,S1,L1,Tcs,Alen1,Tline,A1,Alen1}};
        {A1,Alen1,Ics1,L1,_S1} ->               % Take what we got
            token_cont(Ics1, L1, yyaction(A1, Alen1, Tcs, Tline));
        %% After a non-accepting state, maybe reach accept state later.
        {A1,Alen1,Tlen1,[],L1,S1} ->            % Need more chars to check
            {more,{token,S1,L1,Tcs,Tlen1,Tline,A1,Alen1}};
        {reject,_Alen1,Tlen1,eof,L1,_S1} ->     % No token match
            %% Check for partial token which is error.
            Ret = if Tlen1 > 0 -> {error,{Tline,?MODULE,
                                          %% Skip eof tail in Tcs.
                                          {illegal,yypre(Tcs, Tlen1)}},L1};
                     true -> {eof,L1}
                  end,
            {done,Ret,eof};
        {reject,_Alen1,Tlen1,Ics1,L1,_S1} ->    % No token match
            Error = {Tline,?MODULE,{illegal,yypre(Tcs, Tlen1+1)}},
            {done,{error,Error,L1},Ics1};
        {A1,Alen1,_Tlen1,_Ics1,_L1,_S1} ->       % Use last accept match
            token_cont(yysuf(Tcs, Alen1), L0, yyaction(A1, Alen1, Tcs, Tline))
    end.

%% token_cont(RestChars, Line, Token)
%% If we have a token or error then return done, else if we have a
%% skip_token then continue.

-dialyzer({nowarn_function, token_cont/3}).

token_cont(Rest, Line, {token,T}) ->
    {done,{ok,T,Line},Rest};
token_cont(Rest, Line, {token,T,Push}) ->
    NewRest = Push ++ Rest,
    {done,{ok,T,Line},NewRest};
token_cont(Rest, Line, {end_token,T}) ->
    {done,{ok,T,Line},Rest};
token_cont(Rest, Line, {end_token,T,Push}) ->
    NewRest = Push ++ Rest,
    {done,{ok,T,Line},NewRest};
token_cont(Rest, Line, skip_token) ->
    token(yystate(), Rest, Line, Rest, 0, Line, reject, 0);
token_cont(Rest, Line, {skip_token,Push}) ->
    NewRest = Push ++ Rest,
    token(yystate(), NewRest, Line, NewRest, 0, Line, reject, 0);
token_cont(Rest, Line, {error,S}) ->
    {done,{error,{Line,?MODULE,{user,S}},Line},Rest}.

%% tokens(Continuation, Chars, Line) ->
%% {more,Continuation} | {done,ReturnVal,RestChars}.
%% Must be careful when re-entering to append the latest characters to the
%% after characters in an accept. The continuation is:
%% {tokens,State,CurrLine,TokenChars,TokenLen,TokenLine,Tokens,AccAction,AccLen}
%% {skip_tokens,State,CurrLine,TokenChars,TokenLen,TokenLine,Error,AccAction,AccLen}

tokens(Cont, Chars) -> tokens(Cont, Chars, 1).

tokens([], Chars, Line) ->
    tokens(yystate(), Chars, Line, Chars, 0, Line, [], reject, 0);
tokens({tokens,State,Line,Tcs,Tlen,Tline,Ts,Action,Alen}, Chars, _) ->
    tokens(State, Chars, Line, Tcs ++ Chars, Tlen, Tline, Ts, Action, Alen);
tokens({skip_tokens,State,Line,Tcs,Tlen,Tline,Error,Action,Alen}, Chars, _) ->
    skip_tokens(State, Chars, Line, Tcs ++ Chars, Tlen, Tline, Error, Action, Alen).

%% tokens(State, InChars, Line, TokenChars, TokenLen, TokenLine, Tokens,
%% AcceptAction, AcceptLen) ->
%% {more,Continuation} | {done,ReturnVal,RestChars}.

tokens(S0, Ics0, L0, Tcs, Tlen0, Tline, Ts, A0, Alen0) ->
    case yystate(S0, Ics0, L0, Tlen0, A0, Alen0) of
        %% Accepting end state, we have a token.
        {A1,Alen1,Ics1,L1} ->
            tokens_cont(Ics1, L1, yyaction(A1, Alen1, Tcs, Tline), Ts);
        %% Accepting transition state, can take more chars.
        {A1,Alen1,[],L1,S1} ->                  % Need more chars to check
            {more,{tokens,S1,L1,Tcs,Alen1,Tline,Ts,A1,Alen1}};
        {A1,Alen1,Ics1,L1,_S1} ->               % Take what we got
            tokens_cont(Ics1, L1, yyaction(A1, Alen1, Tcs, Tline), Ts);
        %% After a non-accepting state, maybe reach accept state later.
        {A1,Alen1,Tlen1,[],L1,S1} ->            % Need more chars to check
            {more,{tokens,S1,L1,Tcs,Tlen1,Tline,Ts,A1,Alen1}};
        {reject,_Alen1,Tlen1,eof,L1,_S1} ->     % No token match
            %% Check for partial token which is error, no need to skip here.
            Ret = if Tlen1 > 0 -> {error,{Tline,?MODULE,
                                          %% Skip eof tail in Tcs.
                                          {illegal,yypre(Tcs, Tlen1)}},L1};
                     Ts == [] -> {eof,L1};
                     true -> {ok,yyrev(Ts),L1}
                  end,
            {done,Ret,eof};
        {reject,_Alen1,Tlen1,_Ics1,L1,_S1} ->
            %% Skip rest of tokens.
            Error = {L1,?MODULE,{illegal,yypre(Tcs, Tlen1+1)}},
            skip_tokens(yysuf(Tcs, Tlen1+1), L1, Error);
        {A1,Alen1,_Tlen1,_Ics1,_L1,_S1} ->
            Token = yyaction(A1, Alen1, Tcs, Tline),
            tokens_cont(yysuf(Tcs, Alen1), L0, Token, Ts)
    end.

%% tokens_cont(RestChars, Line, Token, Tokens)
%% If we have an end_token or error then return done, else if we have
%% a token then save it and continue, else if we have a skip_token
%% just continue.

-dialyzer({nowarn_function, tokens_cont/4}).

tokens_cont(Rest, Line, {token,T}, Ts) ->
    tokens(yystate(), Rest, Line, Rest, 0, Line, [T|Ts], reject, 0);
tokens_cont(Rest, Line, {token,T,Push}, Ts) ->
    NewRest = Push ++ Rest,
    tokens(yystate(), NewRest, Line, NewRest, 0, Line, [T|Ts], reject, 0);
tokens_cont(Rest, Line, {end_token,T}, Ts) ->
    {done,{ok,yyrev(Ts, [T]),Line},Rest};
tokens_cont(Rest, Line, {end_token,T,Push}, Ts) ->
    NewRest = Push ++ Rest,
    {done,{ok,yyrev(Ts, [T]),Line},NewRest};
tokens_cont(Rest, Line, skip_token, Ts) ->
    tokens(yystate(), Rest, Line, Rest, 0, Line, Ts, reject, 0);
tokens_cont(Rest, Line, {skip_token,Push}, Ts) ->
    NewRest = Push ++ Rest,
    tokens(yystate(), NewRest, Line, NewRest, 0, Line, Ts, reject, 0);
tokens_cont(Rest, Line, {error,S}, _Ts) ->
    skip_tokens(Rest, Line, {Line,?MODULE,{user,S}}).

%%skip_tokens(InChars, Line, Error) -> {done,{error,Error,Line},Ics}.
%% Skip tokens until an end token, junk everything and return the error.

skip_tokens(Ics, Line, Error) ->
    skip_tokens(yystate(), Ics, Line, Ics, 0, Line, Error, reject, 0).

%% skip_tokens(State, InChars, Line, TokenChars, TokenLen, TokenLine, Tokens,
%% AcceptAction, AcceptLen) ->
%% {more,Continuation} | {done,ReturnVal,RestChars}.

skip_tokens(S0, Ics0, L0, Tcs, Tlen0, Tline, Error, A0, Alen0) ->
    case yystate(S0, Ics0, L0, Tlen0, A0, Alen0) of
        {A1,Alen1,Ics1,L1} ->                  % Accepting end state
            skip_cont(Ics1, L1, yyaction(A1, Alen1, Tcs, Tline), Error);
        {A1,Alen1,[],L1,S1} ->                 % After an accepting state
            {more,{skip_tokens,S1,L1,Tcs,Alen1,Tline,Error,A1,Alen1}};
        {A1,Alen1,Ics1,L1,_S1} ->
            skip_cont(Ics1, L1, yyaction(A1, Alen1, Tcs, Tline), Error);
        {A1,Alen1,Tlen1,[],L1,S1} ->           % After a non-accepting state
            {more,{skip_tokens,S1,L1,Tcs,Tlen1,Tline,Error,A1,Alen1}};
        {reject,_Alen1,_Tlen1,eof,L1,_S1} ->
            {done,{error,Error,L1},eof};
        {reject,_Alen1,Tlen1,_Ics1,L1,_S1} ->
            skip_tokens(yysuf(Tcs, Tlen1+1), L1, Error);
        {A1,Alen1,_Tlen1,_Ics1,L1,_S1} ->
            Token = yyaction(A1, Alen1, Tcs, Tline),
            skip_cont(yysuf(Tcs, Alen1), L1, Token, Error)
    end.

%% skip_cont(RestChars, Line, Token, Error)
%% Skip tokens until we have an end_token or error then return done
%% with the original rror.

-dialyzer({nowarn_function, skip_cont/4}).

skip_cont(Rest, Line, {token,_T}, Error) ->
    skip_tokens(yystate(), Rest, Line, Rest, 0, Line, Error, reject, 0);
skip_cont(Rest, Line, {token,_T,Push}, Error) ->
    NewRest = Push ++ Rest,
    skip_tokens(yystate(), NewRest, Line, NewRest, 0, Line, Error, reject, 0);
skip_cont(Rest, Line, {end_token,_T}, Error) ->
    {done,{error,Error,Line},Rest};
skip_cont(Rest, Line, {end_token,_T,Push}, Error) ->
    NewRest = Push ++ Rest,
    {done,{error,Error,Line},NewRest};
skip_cont(Rest, Line, skip_token, Error) ->
    skip_tokens(yystate(), Rest, Line, Rest, 0, Line, Error, reject, 0);
skip_cont(Rest, Line, {skip_token,Push}, Error) ->
    NewRest = Push ++ Rest,
    skip_tokens(yystate(), NewRest, Line, NewRest, 0, Line, Error, reject, 0);
skip_cont(Rest, Line, {error,_S}, Error) ->
    skip_tokens(yystate(), Rest, Line, Rest, 0, Line, Error, reject, 0).

yyrev(List) -> lists:reverse(List).
yyrev(List, Tail) -> lists:reverse(List, Tail).
yypre(List, N) -> lists:sublist(List, N).
yysuf(List, N) -> lists:nthtail(N, List).

%% yystate() -> InitialState.
%% yystate(State, InChars, Line, CurrTokLen, AcceptAction, AcceptLen) ->
%% {Action, AcceptLen, RestChars, Line} |
%% {Action, AcceptLen, RestChars, Line, State} |
%% {reject, AcceptLen, CurrTokLen, RestChars, Line, State} |
%% {Action, AcceptLen, CurrTokLen, RestChars, Line, State}.
%% Generated state transition functions. The non-accepting end state
%% return signal either an unrecognised character or end of current
%% input.

-file("src/lfe_scan.erl", 391).
yystate() -> 61.

yystate(64, [C|Ics], Line, Tlen, _, _) when C >= 48, C =< 57 ->
    yystate(64, Ics, Line, Tlen+1, 21, Tlen);
yystate(64, [C|Ics], Line, Tlen, _, _) when C >= 65, C =< 70 ->
    yystate(64, Ics, Line, Tlen+1, 21, Tlen);
yystate(64, [C|Ics], Line, Tlen, _, _) when C >= 97, C =< 102 ->
    yystate(64, Ics, Line, Tlen+1, 21, Tlen);
yystate(64, Ics, Line, Tlen, _, _) ->
    {21,Tlen,Ics,Line,64};
yystate(63, [59|Ics], Line, Tlen, _, _) ->
    yystate(29, Ics, Line, Tlen+1, 26, Tlen);
yystate(63, [10|Ics], Line, Tlen, _, _) ->
    yystate(63, Ics, Line+1, Tlen+1, 26, Tlen);
yystate(63, [C|Ics], Line, Tlen, _, _) when C >= 0, C =< 9 ->
    yystate(63, Ics, Line, Tlen+1, 26, Tlen);
yystate(63, [C|Ics], Line, Tlen, _, _) when C >= 11, C =< 32 ->
    yystate(63, Ics, Line, Tlen+1, 26, Tlen);
yystate(63, Ics, Line, Tlen, _, _) ->
    {26,Tlen,Ics,Line,63};
yystate(62, [C|Ics], Line, Tlen, Action, Alen) when C >= 48, C =< 57 ->
    yystate(64, Ics, Line, Tlen+1, Action, Alen);
yystate(62, [C|Ics], Line, Tlen, Action, Alen) when C >= 65, C =< 70 ->
    yystate(64, Ics, Line, Tlen+1, Action, Alen);
yystate(62, [C|Ics], Line, Tlen, Action, Alen) when C >= 97, C =< 102 ->
    yystate(64, Ics, Line, Tlen+1, Action, Alen);
yystate(62, Ics, Line, Tlen, Action, Alen) ->
    {Action,Alen,Tlen,Ics,Line,62};
yystate(61, [125|Ics], Line, Tlen, Action, Alen) ->
    yystate(14, Ics, Line, Tlen+1, Action, Alen);
yystate(61, [124|Ics], Line, Tlen, Action, Alen) ->
    yystate(57, Ics, Line, Tlen+1, Action, Alen);
yystate(61, [123|Ics], Line, Tlen, Action, Alen) ->
    yystate(14, Ics, Line, Tlen+1, Action, Alen);
yystate(61, [96|Ics], Line, Tlen, Action, Alen) ->
    yystate(33, Ics, Line, Tlen+1, Action, Alen);
yystate(61, [94|Ics], Line, Tlen, Action, Alen) ->
    yystate(59, Ics, Line, Tlen+1, Action, Alen);
yystate(61, [95|Ics], Line, Tlen, Action, Alen) ->
    yystate(59, Ics, Line, Tlen+1, Action, Alen);
yystate(61, [93|Ics], Line, Tlen, Action, Alen) ->
    yystate(14, Ics, Line, Tlen+1, Action, Alen);
yystate(61, [92|Ics], Line, Tlen, Action, Alen) ->
    yystate(59, Ics, Line, Tlen+1, Action, Alen);
yystate(61, [91|Ics], Line, Tlen, Action, Alen) ->
    yystate(14, Ics, Line, Tlen+1, Action, Alen);
yystate(61, [59|Ics], Line, Tlen, Action, Alen) ->
    yystate(29, Ics, Line, Tlen+1, Action, Alen);
yystate(61, [58|Ics], Line, Tlen, Action, Alen) ->
    yystate(59, Ics, Line, Tlen+1, Action, Alen);
yystate(61, [47|Ics], Line, Tlen, Action, Alen) ->
    yystate(59, Ics, Line, Tlen+1, Action, Alen);
yystate(61, [46|Ics], Line, Tlen, Action, Alen) ->
    yystate(1, Ics, Line, Tlen+1, Action, Alen);
yystate(61, [45|Ics], Line, Tlen, Action, Alen) ->
    yystate(10, Ics, Line, Tlen+1, Action, Alen);
yystate(61, [44|Ics], Line, Tlen, Action, Alen) ->
    yystate(2, Ics, Line, Tlen+1, Action, Alen);
yystate(61, [43|Ics], Line, Tlen, Action, Alen) ->
    yystate(10, Ics, Line, Tlen+1, Action, Alen);
yystate(61, [42|Ics], Line, Tlen, Action, Alen) ->
    yystate(59, Ics, Line, Tlen+1, Action, Alen);
yystate(61, [40|Ics], Line, Tlen, Action, Alen) ->
    yystate(14, Ics, Line, Tlen+1, Action, Alen);
yystate(61, [41|Ics], Line, Tlen, Action, Alen) ->
    yystate(14, Ics, Line, Tlen+1, Action, Alen);
yystate(61, [39|Ics], Line, Tlen, Action, Alen) ->
    yystate(18, Ics, Line, Tlen+1, Action, Alen);
yystate(61, [35|Ics], Line, Tlen, Action, Alen) ->
    yystate(22, Ics, Line, Tlen+1, Action, Alen);
yystate(61, [34|Ics], Line, Tlen, Action, Alen) ->
    yystate(55, Ics, Line, Tlen+1, Action, Alen);
yystate(61, [33|Ics], Line, Tlen, Action, Alen) ->
    yystate(59, Ics, Line, Tlen+1, Action, Alen);
yystate(61, [10|Ics], Line, Tlen, Action, Alen) ->
    yystate(63, Ics, Line+1, Tlen+1, Action, Alen);
yystate(61, [C|Ics], Line, Tlen, Action, Alen) when C >= 0, C =< 9 ->
    yystate(63, Ics, Line, Tlen+1, Action, Alen);
yystate(61, [C|Ics], Line, Tlen, Action, Alen) when C >= 11, C =< 32 ->
    yystate(63, Ics, Line, Tlen+1, Action, Alen);
yystate(61, [C|Ics], Line, Tlen, Action, Alen) when C >= 36, C =< 38 ->
    yystate(59, Ics, Line, Tlen+1, Action, Alen);
yystate(61, [C|Ics], Line, Tlen, Action, Alen) when C >= 48, C =< 57 ->
    yystate(25, Ics, Line, Tlen+1, Action, Alen);
yystate(61, [C|Ics], Line, Tlen, Action, Alen) when C >= 60, C =< 90 ->
    yystate(59, Ics, Line, Tlen+1, Action, Alen);
yystate(61, [C|Ics], Line, Tlen, Action, Alen) when C >= 97, C =< 122 ->
    yystate(59, Ics, Line, Tlen+1, Action, Alen);
yystate(61, [C|Ics], Line, Tlen, Action, Alen) when C >= 126 ->
    yystate(59, Ics, Line, Tlen+1, Action, Alen);
yystate(61, Ics, Line, Tlen, Action, Alen) ->
    {Action,Alen,Tlen,Ics,Line,61};
yystate(60, [C|Ics], Line, Tlen, Action, Alen) when C >= 48, C =< 55 ->
    yystate(56, Ics, Line, Tlen+1, Action, Alen);
yystate(60, Ics, Line, Tlen, Action, Alen) ->
    {Action,Alen,Tlen,Ics,Line,60};
yystate(59, [124|Ics], Line, Tlen, _, _) ->
    yystate(59, Ics, Line, Tlen+1, 25, Tlen);
yystate(59, [92|Ics], Line, Tlen, _, _) ->
    yystate(59, Ics, Line, Tlen+1, 25, Tlen);
yystate(59, [33|Ics], Line, Tlen, _, _) ->
    yystate(59, Ics, Line, Tlen+1, 25, Tlen);
yystate(59, [C|Ics], Line, Tlen, _, _) when C >= 35, C =< 39 ->
    yystate(59, Ics, Line, Tlen+1, 25, Tlen);
yystate(59, [C|Ics], Line, Tlen, _, _) when C >= 42, C =< 58 ->
    yystate(59, Ics, Line, Tlen+1, 25, Tlen);
yystate(59, [C|Ics], Line, Tlen, _, _) when C >= 60, C =< 90 ->
    yystate(59, Ics, Line, Tlen+1, 25, Tlen);
yystate(59, [C|Ics], Line, Tlen, _, _) when C >= 94, C =< 122 ->
    yystate(59, Ics, Line, Tlen+1, 25, Tlen);
yystate(59, [C|Ics], Line, Tlen, _, _) when C >= 126 ->
    yystate(59, Ics, Line, Tlen+1, 25, Tlen);
yystate(59, Ics, Line, Tlen, _, _) ->
    {25,Tlen,Ics,Line,59};
yystate(58, Ics, Line, Tlen, _, _) ->
    {14,Tlen,Ics,Line};
yystate(57, [124|Ics], Line, Tlen, Action, Alen) ->
    yystate(53, Ics, Line, Tlen+1, Action, Alen);
yystate(57, [92|Ics], Line, Tlen, Action, Alen) ->
    yystate(49, Ics, Line, Tlen+1, Action, Alen);
yystate(57, [10|Ics], Line, Tlen, Action, Alen) ->
    yystate(57, Ics, Line+1, Tlen+1, Action, Alen);
yystate(57, [C|Ics], Line, Tlen, Action, Alen) when C >= 0, C =< 9 ->
    yystate(57, Ics, Line, Tlen+1, Action, Alen);
yystate(57, [C|Ics], Line, Tlen, Action, Alen) when C >= 11, C =< 91 ->
    yystate(57, Ics, Line, Tlen+1, Action, Alen);
yystate(57, [C|Ics], Line, Tlen, Action, Alen) when C >= 93, C =< 123 ->
    yystate(57, Ics, Line, Tlen+1, Action, Alen);
yystate(57, [C|Ics], Line, Tlen, Action, Alen) when C >= 125 ->
    yystate(57, Ics, Line, Tlen+1, Action, Alen);
yystate(57, Ics, Line, Tlen, Action, Alen) ->
    {Action,Alen,Tlen,Ics,Line,57};
yystate(56, [C|Ics], Line, Tlen, _, _) when C >= 48, C =< 55 ->
    yystate(56, Ics, Line, Tlen+1, 19, Tlen);
yystate(56, Ics, Line, Tlen, _, _) ->
    {19,Tlen,Ics,Line,56};
yystate(55, [92|Ics], Line, Tlen, Action, Alen) ->
    yystate(43, Ics, Line, Tlen+1, Action, Alen);
yystate(55, [34|Ics], Line, Tlen, Action, Alen) ->
    yystate(51, Ics, Line, Tlen+1, Action, Alen);
yystate(55, [10|Ics], Line, Tlen, Action, Alen) ->
    yystate(55, Ics, Line+1, Tlen+1, Action, Alen);
yystate(55, [C|Ics], Line, Tlen, Action, Alen) when C >= 0, C =< 9 ->
    yystate(55, Ics, Line, Tlen+1, Action, Alen);
yystate(55, [C|Ics], Line, Tlen, Action, Alen) when C >= 11, C =< 33 ->
    yystate(55, Ics, Line, Tlen+1, Action, Alen);
yystate(55, [C|Ics], Line, Tlen, Action, Alen) when C >= 35, C =< 91 ->
    yystate(55, Ics, Line, Tlen+1, Action, Alen);
yystate(55, [C|Ics], Line, Tlen, Action, Alen) when C >= 93 ->
    yystate(55, Ics, Line, Tlen+1, Action, Alen);
yystate(55, Ics, Line, Tlen, Action, Alen) ->
    {Action,Alen,Tlen,Ics,Line,55};
yystate(54, [C|Ics], Line, Tlen, _, _) when C >= 48, C =< 57 ->
    yystate(54, Ics, Line, Tlen+1, 14, Tlen);
yystate(54, [C|Ics], Line, Tlen, _, _) when C >= 65, C =< 70 ->
    yystate(54, Ics, Line, Tlen+1, 14, Tlen);
yystate(54, [C|Ics], Line, Tlen, _, _) when C >= 97, C =< 102 ->
    yystate(54, Ics, Line, Tlen+1, 14, Tlen);
yystate(54, Ics, Line, Tlen, _, _) ->
    {14,Tlen,Ics,Line,54};
yystate(53, Ics, Line, Tlen, _, _) ->
    {16,Tlen,Ics,Line};
yystate(52, [40|Ics], Line, Tlen, Action, Alen) ->
    yystate(48, Ics, Line, Tlen+1, Action, Alen);
yystate(52, Ics, Line, Tlen, Action, Alen) ->
    {Action,Alen,Tlen,Ics,Line,52};
yystate(51, Ics, Line, Tlen, _, _) ->
    {15,Tlen,Ics,Line};
yystate(50, [120|Ics], Line, Tlen, Action, Alen) ->
    yystate(54, Ics, Line, Tlen+1, Action, Alen);
yystate(50, [C|Ics], Line, Tlen, Action, Alen) when C >= 0, C =< 9 ->
    yystate(58, Ics, Line, Tlen+1, Action, Alen);
yystate(50, [C|Ics], Line, Tlen, Action, Alen) when C >= 11, C =< 119 ->
    yystate(58, Ics, Line, Tlen+1, Action, Alen);
yystate(50, [C|Ics], Line, Tlen, Action, Alen) when C >= 121 ->
    yystate(58, Ics, Line, Tlen+1, Action, Alen);
yystate(50, Ics, Line, Tlen, Action, Alen) ->
    {Action,Alen,Tlen,Ics,Line,50};
yystate(49, [124|Ics], Line, Tlen, Action, Alen) ->
    yystate(45, Ics, Line, Tlen+1, Action, Alen);
yystate(49, [120|Ics], Line, Tlen, Action, Alen) ->
    yystate(41, Ics, Line, Tlen+1, Action, Alen);
yystate(49, [92|Ics], Line, Tlen, Action, Alen) ->
    yystate(49, Ics, Line, Tlen+1, Action, Alen);
yystate(49, [10|Ics], Line, Tlen, Action, Alen) ->
    yystate(57, Ics, Line+1, Tlen+1, Action, Alen);
yystate(49, [C|Ics], Line, Tlen, Action, Alen) when C >= 0, C =< 9 ->
    yystate(57, Ics, Line, Tlen+1, Action, Alen);
yystate(49, [C|Ics], Line, Tlen, Action, Alen) when C >= 11, C =< 91 ->
    yystate(57, Ics, Line, Tlen+1, Action, Alen);
yystate(49, [C|Ics], Line, Tlen, Action, Alen) when C >= 93, C =< 119 ->
    yystate(57, Ics, Line, Tlen+1, Action, Alen);
yystate(49, [C|Ics], Line, Tlen, Action, Alen) when C >= 121, C =< 123 ->
    yystate(57, Ics, Line, Tlen+1, Action, Alen);
yystate(49, [C|Ics], Line, Tlen, Action, Alen) when C >= 125 ->
    yystate(57, Ics, Line, Tlen+1, Action, Alen);
yystate(49, Ics, Line, Tlen, Action, Alen) ->
    {Action,Alen,Tlen,Ics,Line,49};
yystate(48, Ics, Line, Tlen, _, _) ->
    {2,Tlen,Ics,Line};
yystate(47, [92|Ics], Line, Tlen, _, _) ->
    yystate(43, Ics, Line, Tlen+1, 15, Tlen);
yystate(47, [34|Ics], Line, Tlen, _, _) ->
    yystate(51, Ics, Line, Tlen+1, 15, Tlen);
yystate(47, [10|Ics], Line, Tlen, _, _) ->
    yystate(55, Ics, Line+1, Tlen+1, 15, Tlen);
yystate(47, [C|Ics], Line, Tlen, _, _) when C >= 0, C =< 9 ->
    yystate(55, Ics, Line, Tlen+1, 15, Tlen);
yystate(47, [C|Ics], Line, Tlen, _, _) when C >= 11, C =< 33 ->
    yystate(55, Ics, Line, Tlen+1, 15, Tlen);
yystate(47, [C|Ics], Line, Tlen, _, _) when C >= 35, C =< 91 ->
    yystate(55, Ics, Line, Tlen+1, 15, Tlen);
yystate(47, [C|Ics], Line, Tlen, _, _) when C >= 93 ->
    yystate(55, Ics, Line, Tlen+1, 15, Tlen);
yystate(47, Ics, Line, Tlen, _, _) ->
    {15,Tlen,Ics,Line,47};
yystate(46, Ics, Line, Tlen, _, _) ->
    {4,Tlen,Ics,Line};
yystate(45, [124|Ics], Line, Tlen, _, _) ->
    yystate(53, Ics, Line, Tlen+1, 16, Tlen);
yystate(45, [92|Ics], Line, Tlen, _, _) ->
    yystate(49, Ics, Line, Tlen+1, 16, Tlen);
yystate(45, [10|Ics], Line, Tlen, _, _) ->
    yystate(57, Ics, Line+1, Tlen+1, 16, Tlen);
yystate(45, [C|Ics], Line, Tlen, _, _) when C >= 0, C =< 9 ->
    yystate(57, Ics, Line, Tlen+1, 16, Tlen);
yystate(45, [C|Ics], Line, Tlen, _, _) when C >= 11, C =< 91 ->
    yystate(57, Ics, Line, Tlen+1, 16, Tlen);
yystate(45, [C|Ics], Line, Tlen, _, _) when C >= 93, C =< 123 ->
    yystate(57, Ics, Line, Tlen+1, 16, Tlen);
yystate(45, [C|Ics], Line, Tlen, _, _) when C >= 125 ->
    yystate(57, Ics, Line, Tlen+1, 16, Tlen);
yystate(45, Ics, Line, Tlen, _, _) ->
    {16,Tlen,Ics,Line,45};
yystate(44, [C|Ics], Line, Tlen, Action, Alen) when C >= 48, C =< 57 ->
    yystate(40, Ics, Line, Tlen+1, Action, Alen);
yystate(44, Ics, Line, Tlen, Action, Alen) ->
    {Action,Alen,Tlen,Ics,Line,44};
yystate(43, [120|Ics], Line, Tlen, Action, Alen) ->
    yystate(35, Ics, Line, Tlen+1, Action, Alen);
yystate(43, [92|Ics], Line, Tlen, Action, Alen) ->
    yystate(43, Ics, Line, Tlen+1, Action, Alen);
yystate(43, [34|Ics], Line, Tlen, Action, Alen) ->
    yystate(47, Ics, Line, Tlen+1, Action, Alen);
yystate(43, [10|Ics], Line, Tlen, Action, Alen) ->
    yystate(55, Ics, Line+1, Tlen+1, Action, Alen);
yystate(43, [C|Ics], Line, Tlen, Action, Alen) when C >= 0, C =< 9 ->
    yystate(55, Ics, Line, Tlen+1, Action, Alen);
yystate(43, [C|Ics], Line, Tlen, Action, Alen) when C >= 11, C =< 33 ->
    yystate(55, Ics, Line, Tlen+1, Action, Alen);
yystate(43, [C|Ics], Line, Tlen, Action, Alen) when C >= 35, C =< 91 ->
    yystate(55, Ics, Line, Tlen+1, Action, Alen);
yystate(43, [C|Ics], Line, Tlen, Action, Alen) when C >= 93, C =< 119 ->
    yystate(55, Ics, Line, Tlen+1, Action, Alen);
yystate(43, [C|Ics], Line, Tlen, Action, Alen) when C >= 121 ->
    yystate(55, Ics, Line, Tlen+1, Action, Alen);
yystate(43, Ics, Line, Tlen, Action, Alen) ->
    {Action,Alen,Tlen,Ics,Line,43};
yystate(42, [124|Ics], Line, Tlen, Action, Alen) ->
    yystate(42, Ics, Line, Tlen+1, Action, Alen);
yystate(42, [35|Ics], Line, Tlen, Action, Alen) ->
    yystate(34, Ics, Line, Tlen+1, Action, Alen);
yystate(42, [10|Ics], Line, Tlen, Action, Alen) ->
    yystate(38, Ics, Line+1, Tlen+1, Action, Alen);
yystate(42, [C|Ics], Line, Tlen, Action, Alen) when C >= 0, C =< 9 ->
    yystate(38, Ics, Line, Tlen+1, Action, Alen);
yystate(42, [C|Ics], Line, Tlen, Action, Alen) when C >= 11, C =< 34 ->
    yystate(38, Ics, Line, Tlen+1, Action, Alen);
yystate(42, [C|Ics], Line, Tlen, Action, Alen) when C >= 36, C =< 123 ->
    yystate(38, Ics, Line, Tlen+1, Action, Alen);
yystate(42, [C|Ics], Line, Tlen, Action, Alen) when C >= 125 ->
    yystate(38, Ics, Line, Tlen+1, Action, Alen);
yystate(42, Ics, Line, Tlen, Action, Alen) ->
    {Action,Alen,Tlen,Ics,Line,42};
yystate(41, [124|Ics], Line, Tlen, Action, Alen) ->
    yystate(53, Ics, Line, Tlen+1, Action, Alen);
yystate(41, [92|Ics], Line, Tlen, Action, Alen) ->
    yystate(49, Ics, Line, Tlen+1, Action, Alen);
yystate(41, [10|Ics], Line, Tlen, Action, Alen) ->
    yystate(57, Ics, Line+1, Tlen+1, Action, Alen);
yystate(41, [C|Ics], Line, Tlen, Action, Alen) when C >= 0, C =< 9 ->
    yystate(57, Ics, Line, Tlen+1, Action, Alen);
yystate(41, [C|Ics], Line, Tlen, Action, Alen) when C >= 11, C =< 47 ->
    yystate(57, Ics, Line, Tlen+1, Action, Alen);
yystate(41, [C|Ics], Line, Tlen, Action, Alen) when C >= 48, C =< 57 ->
    yystate(37, Ics, Line, Tlen+1, Action, Alen);
yystate(41, [C|Ics], Line, Tlen, Action, Alen) when C >= 58, C =< 64 ->
    yystate(57, Ics, Line, Tlen+1, Action, Alen);
yystate(41, [C|Ics], Line, Tlen, Action, Alen) when C >= 65, C =< 70 ->
    yystate(37, Ics, Line, Tlen+1, Action, Alen);
yystate(41, [C|Ics], Line, Tlen, Action, Alen) when C >= 71, C =< 91 ->
    yystate(57, Ics, Line, Tlen+1, Action, Alen);
yystate(41, [C|Ics], Line, Tlen, Action, Alen) when C >= 93, C =< 96 ->
    yystate(57, Ics, Line, Tlen+1, Action, Alen);
yystate(41, [C|Ics], Line, Tlen, Action, Alen) when C >= 97, C =< 102 ->
    yystate(37, Ics, Line, Tlen+1, Action, Alen);
yystate(41, [C|Ics], Line, Tlen, Action, Alen) when C >= 103, C =< 123 ->
    yystate(57, Ics, Line, Tlen+1, Action, Alen);
yystate(41, [C|Ics], Line, Tlen, Action, Alen) when C >= 125 ->
    yystate(57, Ics, Line, Tlen+1, Action, Alen);
yystate(41, Ics, Line, Tlen, Action, Alen) ->
    {Action,Alen,Tlen,Ics,Line,41};
yystate(40, [C|Ics], Line, Tlen, _, _) when C >= 48, C =< 57 ->
    yystate(40, Ics, Line, Tlen+1, 20, Tlen);
yystate(40, Ics, Line, Tlen, _, _) ->
    {20,Tlen,Ics,Line,40};
yystate(39, [92|Ics], Line, Tlen, Action, Alen) ->
    yystate(43, Ics, Line, Tlen+1, Action, Alen);
yystate(39, [59|Ics], Line, Tlen, Action, Alen) ->
    yystate(55, Ics, Line, Tlen+1, Action, Alen);
yystate(39, [58|Ics], Line, Tlen, Action, Alen) ->
    yystate(55, Ics, Line, Tlen+1, Action, Alen);
yystate(39, [34|Ics], Line, Tlen, Action, Alen) ->
    yystate(51, Ics, Line, Tlen+1, Action, Alen);
yystate(39, [10|Ics], Line, Tlen, Action, Alen) ->
    yystate(55, Ics, Line+1, Tlen+1, Action, Alen);
yystate(39, [C|Ics], Line, Tlen, Action, Alen) when C >= 0, C =< 9 ->
    yystate(55, Ics, Line, Tlen+1, Action, Alen);
yystate(39, [C|Ics], Line, Tlen, Action, Alen) when C >= 11, C =< 33 ->
    yystate(55, Ics, Line, Tlen+1, Action, Alen);
yystate(39, [C|Ics], Line, Tlen, Action, Alen) when C >= 35, C =< 47 ->
    yystate(55, Ics, Line, Tlen+1, Action, Alen);
yystate(39, [C|Ics], Line, Tlen, Action, Alen) when C >= 48, C =< 57 ->
    yystate(39, Ics, Line, Tlen+1, Action, Alen);
yystate(39, [C|Ics], Line, Tlen, Action, Alen) when C >= 60, C =< 64 ->
    yystate(55, Ics, Line, Tlen+1, Action, Alen);
yystate(39, [C|Ics], Line, Tlen, Action, Alen) when C >= 65, C =< 70 ->
    yystate(39, Ics, Line, Tlen+1, Action, Alen);
yystate(39, [C|Ics], Line, Tlen, Action, Alen) when C >= 71, C =< 91 ->
    yystate(55, Ics, Line, Tlen+1, Action, Alen);
yystate(39, [C|Ics], Line, Tlen, Action, Alen) when C >= 93, C =< 96 ->
    yystate(55, Ics, Line, Tlen+1, Action, Alen);
yystate(39, [C|Ics], Line, Tlen, Action, Alen) when C >= 97, C =< 102 ->
    yystate(39, Ics, Line, Tlen+1, Action, Alen);
yystate(39, [C|Ics], Line, Tlen, Action, Alen) when C >= 103 ->
    yystate(55, Ics, Line, Tlen+1, Action, Alen);
yystate(39, Ics, Line, Tlen, Action, Alen) ->
    {Action,Alen,Tlen,Ics,Line,39};
yystate(38, [124|Ics], Line, Tlen, Action, Alen) ->
    yystate(42, Ics, Line, Tlen+1, Action, Alen);
yystate(38, [10|Ics], Line, Tlen, Action, Alen) ->
    yystate(38, Ics, Line+1, Tlen+1, Action, Alen);
yystate(38, [C|Ics], Line, Tlen, Action, Alen) when C >= 0, C =< 9 ->
    yystate(38, Ics, Line, Tlen+1, Action, Alen);
yystate(38, [C|Ics], Line, Tlen, Action, Alen) when C >= 11, C =< 123 ->
    yystate(38, Ics, Line, Tlen+1, Action, Alen);
yystate(38, [C|Ics], Line, Tlen, Action, Alen) when C >= 125 ->
    yystate(38, Ics, Line, Tlen+1, Action, Alen);
yystate(38, Ics, Line, Tlen, Action, Alen) ->
    {Action,Alen,Tlen,Ics,Line,38};
yystate(37, [124|Ics], Line, Tlen, Action, Alen) ->
    yystate(53, Ics, Line, Tlen+1, Action, Alen);
yystate(37, [92|Ics], Line, Tlen, Action, Alen) ->
    yystate(49, Ics, Line, Tlen+1, Action, Alen);
yystate(37, [59|Ics], Line, Tlen, Action, Alen) ->
    yystate(57, Ics, Line, Tlen+1, Action, Alen);
yystate(37, [58|Ics], Line, Tlen, Action, Alen) ->
    yystate(57, Ics, Line, Tlen+1, Action, Alen);
yystate(37, [10|Ics], Line, Tlen, Action, Alen) ->
    yystate(57, Ics, Line+1, Tlen+1, Action, Alen);
yystate(37, [C|Ics], Line, Tlen, Action, Alen) when C >= 0, C =< 9 ->
    yystate(57, Ics, Line, Tlen+1, Action, Alen);
yystate(37, [C|Ics], Line, Tlen, Action, Alen) when C >= 11, C =< 47 ->
    yystate(57, Ics, Line, Tlen+1, Action, Alen);
yystate(37, [C|Ics], Line, Tlen, Action, Alen) when C >= 48, C =< 57 ->
    yystate(37, Ics, Line, Tlen+1, Action, Alen);
yystate(37, [C|Ics], Line, Tlen, Action, Alen) when C >= 60, C =< 64 ->
    yystate(57, Ics, Line, Tlen+1, Action, Alen);
yystate(37, [C|Ics], Line, Tlen, Action, Alen) when C >= 65, C =< 70 ->
    yystate(37, Ics, Line, Tlen+1, Action, Alen);
yystate(37, [C|Ics], Line, Tlen, Action, Alen) when C >= 71, C =< 91 ->
    yystate(57, Ics, Line, Tlen+1, Action, Alen);
yystate(37, [C|Ics], Line, Tlen, Action, Alen) when C >= 93, C =< 96 ->
    yystate(57, Ics, Line, Tlen+1, Action, Alen);
yystate(37, [C|Ics], Line, Tlen, Action, Alen) when C >= 97, C =< 102 ->
    yystate(37, Ics, Line, Tlen+1, Action, Alen);
yystate(37, [C|Ics], Line, Tlen, Action, Alen) when C >= 103, C =< 123 ->
    yystate(57, Ics, Line, Tlen+1, Action, Alen);
yystate(37, [C|Ics], Line, Tlen, Action, Alen) when C >= 125 ->
    yystate(57, Ics, Line, Tlen+1, Action, Alen);
yystate(37, Ics, Line, Tlen, Action, Alen) ->
    {Action,Alen,Tlen,Ics,Line,37};
yystate(36, [48|Ics], Line, Tlen, Action, Alen) ->
    yystate(32, Ics, Line, Tlen+1, Action, Alen);
yystate(36, [49|Ics], Line, Tlen, Action, Alen) ->
    yystate(32, Ics, Line, Tlen+1, Action, Alen);
yystate(36, [40|Ics], Line, Tlen, Action, Alen) ->
    yystate(28, Ics, Line, Tlen+1, Action, Alen);
yystate(36, Ics, Line, Tlen, Action, Alen) ->
    {Action,Alen,Tlen,Ics,Line,36};
yystate(35, [92|Ics], Line, Tlen, Action, Alen) ->
    yystate(43, Ics, Line, Tlen+1, Action, Alen);
yystate(35, [34|Ics], Line, Tlen, Action, Alen) ->
    yystate(51, Ics, Line, Tlen+1, Action, Alen);
yystate(35, [10|Ics], Line, Tlen, Action, Alen) ->
    yystate(55, Ics, Line+1, Tlen+1, Action, Alen);
yystate(35, [C|Ics], Line, Tlen, Action, Alen) when C >= 0, C =< 9 ->
    yystate(55, Ics, Line, Tlen+1, Action, Alen);
yystate(35, [C|Ics], Line, Tlen, Action, Alen) when C >= 11, C =< 33 ->
    yystate(55, Ics, Line, Tlen+1, Action, Alen);
yystate(35, [C|Ics], Line, Tlen, Action, Alen) when C >= 35, C =< 47 ->
    yystate(55, Ics, Line, Tlen+1, Action, Alen);
yystate(35, [C|Ics], Line, Tlen, Action, Alen) when C >= 48, C =< 57 ->
    yystate(39, Ics, Line, Tlen+1, Action, Alen);
yystate(35, [C|Ics], Line, Tlen, Action, Alen) when C >= 58, C =< 64 ->
    yystate(55, Ics, Line, Tlen+1, Action, Alen);
yystate(35, [C|Ics], Line, Tlen, Action, Alen) when C >= 65, C =< 70 ->
    yystate(39, Ics, Line, Tlen+1, Action, Alen);
yystate(35, [C|Ics], Line, Tlen, Action, Alen) when C >= 71, C =< 91 ->
    yystate(55, Ics, Line, Tlen+1, Action, Alen);
yystate(35, [C|Ics], Line, Tlen, Action, Alen) when C >= 93, C =< 96 ->
    yystate(55, Ics, Line, Tlen+1, Action, Alen);
yystate(35, [C|Ics], Line, Tlen, Action, Alen) when C >= 97, C =< 102 ->
    yystate(39, Ics, Line, Tlen+1, Action, Alen);
yystate(35, [C|Ics], Line, Tlen, Action, Alen) when C >= 103 ->
    yystate(55, Ics, Line, Tlen+1, Action, Alen);
yystate(35, Ics, Line, Tlen, Action, Alen) ->
    {Action,Alen,Tlen,Ics,Line,35};
yystate(34, Ics, Line, Tlen, _, _) ->
    {0,Tlen,Ics,Line};
yystate(33, Ics, Line, Tlen, _, _) ->
    {9,Tlen,Ics,Line};
yystate(32, [48|Ics], Line, Tlen, _, _) ->
    yystate(32, Ics, Line, Tlen+1, 18, Tlen);
yystate(32, [49|Ics], Line, Tlen, _, _) ->
    yystate(32, Ics, Line, Tlen+1, 18, Tlen);
yystate(32, Ics, Line, Tlen, _, _) ->
    {18,Tlen,Ics,Line,32};
yystate(31, [124|Ics], Line, Tlen, Action, Alen) ->
    yystate(31, Ics, Line, Tlen+1, Action, Alen);
yystate(31, [92|Ics], Line, Tlen, Action, Alen) ->
    yystate(31, Ics, Line, Tlen+1, Action, Alen);
yystate(31, [47|Ics], Line, Tlen, Action, Alen) ->
    yystate(23, Ics, Line, Tlen+1, Action, Alen);
yystate(31, [33|Ics], Line, Tlen, Action, Alen) ->
    yystate(31, Ics, Line, Tlen+1, Action, Alen);
yystate(31, [C|Ics], Line, Tlen, Action, Alen) when C >= 35, C =< 39 ->
    yystate(31, Ics, Line, Tlen+1, Action, Alen);
yystate(31, [C|Ics], Line, Tlen, Action, Alen) when C >= 42, C =< 46 ->
    yystate(31, Ics, Line, Tlen+1, Action, Alen);
yystate(31, [C|Ics], Line, Tlen, Action, Alen) when C >= 48, C =< 58 ->
    yystate(31, Ics, Line, Tlen+1, Action, Alen);
yystate(31, [C|Ics], Line, Tlen, Action, Alen) when C >= 60, C =< 90 ->
    yystate(31, Ics, Line, Tlen+1, Action, Alen);
yystate(31, [C|Ics], Line, Tlen, Action, Alen) when C >= 94, C =< 122 ->
    yystate(31, Ics, Line, Tlen+1, Action, Alen);
yystate(31, [C|Ics], Line, Tlen, Action, Alen) when C >= 126 ->
    yystate(31, Ics, Line, Tlen+1, Action, Alen);
yystate(31, Ics, Line, Tlen, Action, Alen) ->
    {Action,Alen,Tlen,Ics,Line,31};
yystate(30, [124|Ics], Line, Tlen, Action, Alen) ->
    yystate(30, Ics, Line, Tlen+1, Action, Alen);
yystate(30, [35|Ics], Line, Tlen, Action, Alen) ->
    yystate(34, Ics, Line, Tlen+1, Action, Alen);
yystate(30, [10|Ics], Line, Tlen, Action, Alen) ->
    yystate(38, Ics, Line+1, Tlen+1, Action, Alen);
yystate(30, [C|Ics], Line, Tlen, Action, Alen) when C >= 0, C =< 9 ->
    yystate(38, Ics, Line, Tlen+1, Action, Alen);
yystate(30, [C|Ics], Line, Tlen, Action, Alen) when C >= 11, C =< 34 ->
    yystate(38, Ics, Line, Tlen+1, Action, Alen);
yystate(30, [C|Ics], Line, Tlen, Action, Alen) when C >= 36, C =< 123 ->
    yystate(38, Ics, Line, Tlen+1, Action, Alen);
yystate(30, [C|Ics], Line, Tlen, Action, Alen) when C >= 125 ->
    yystate(38, Ics, Line, Tlen+1, Action, Alen);
yystate(30, Ics, Line, Tlen, Action, Alen) ->
    {Action,Alen,Tlen,Ics,Line,30};
yystate(29, [59|Ics], Line, Tlen, _, _) ->
    yystate(29, Ics, Line, Tlen+1, 26, Tlen);
yystate(29, [10|Ics], Line, Tlen, _, _) ->
    yystate(63, Ics, Line+1, Tlen+1, 26, Tlen);
yystate(29, [C|Ics], Line, Tlen, _, _) when C >= 0, C =< 9 ->
    yystate(29, Ics, Line, Tlen+1, 26, Tlen);
yystate(29, [C|Ics], Line, Tlen, _, _) when C >= 11, C =< 32 ->
    yystate(29, Ics, Line, Tlen+1, 26, Tlen);
yystate(29, [C|Ics], Line, Tlen, _, _) when C >= 33, C =< 58 ->
    yystate(29, Ics, Line, Tlen+1, 26, Tlen);
yystate(29, [C|Ics], Line, Tlen, _, _) when C >= 60 ->
    yystate(29, Ics, Line, Tlen+1, 26, Tlen);
yystate(29, Ics, Line, Tlen, _, _) ->
    {26,Tlen,Ics,Line,29};
yystate(28, Ics, Line, Tlen, _, _) ->
    {1,Tlen,Ics,Line};
yystate(27, [124|Ics], Line, Tlen, _, _) ->
    yystate(31, Ics, Line, Tlen+1, 17, Tlen);
yystate(27, [92|Ics], Line, Tlen, _, _) ->
    yystate(31, Ics, Line, Tlen+1, 17, Tlen);
yystate(27, [58|Ics], Line, Tlen, _, _) ->
    yystate(31, Ics, Line, Tlen+1, 17, Tlen);
yystate(27, [47|Ics], Line, Tlen, _, _) ->
    yystate(23, Ics, Line, Tlen+1, 17, Tlen);
yystate(27, [33|Ics], Line, Tlen, _, _) ->
    yystate(31, Ics, Line, Tlen+1, 17, Tlen);
yystate(27, [C|Ics], Line, Tlen, _, _) when C >= 35, C =< 39 ->
    yystate(31, Ics, Line, Tlen+1, 17, Tlen);
yystate(27, [C|Ics], Line, Tlen, _, _) when C >= 42, C =< 46 ->
    yystate(31, Ics, Line, Tlen+1, 17, Tlen);
yystate(27, [C|Ics], Line, Tlen, _, _) when C >= 48, C =< 57 ->
    yystate(27, Ics, Line, Tlen+1, 17, Tlen);
yystate(27, [C|Ics], Line, Tlen, _, _) when C >= 60, C =< 90 ->
    yystate(31, Ics, Line, Tlen+1, 17, Tlen);
yystate(27, [C|Ics], Line, Tlen, _, _) when C >= 94, C =< 122 ->
    yystate(31, Ics, Line, Tlen+1, 17, Tlen);
yystate(27, [C|Ics], Line, Tlen, _, _) when C >= 126 ->
    yystate(31, Ics, Line, Tlen+1, 17, Tlen);
yystate(27, Ics, Line, Tlen, _, _) ->
    {17,Tlen,Ics,Line,27};
yystate(26, [124|Ics], Line, Tlen, Action, Alen) ->
    yystate(30, Ics, Line, Tlen+1, Action, Alen);
yystate(26, [10|Ics], Line, Tlen, Action, Alen) ->
    yystate(26, Ics, Line+1, Tlen+1, Action, Alen);
yystate(26, [C|Ics], Line, Tlen, Action, Alen) when C >= 0, C =< 9 ->
    yystate(26, Ics, Line, Tlen+1, Action, Alen);
yystate(26, [C|Ics], Line, Tlen, Action, Alen) when C >= 11, C =< 123 ->
    yystate(26, Ics, Line, Tlen+1, Action, Alen);
yystate(26, [C|Ics], Line, Tlen, Action, Alen) when C >= 125 ->
    yystate(26, Ics, Line, Tlen+1, Action, Alen);
yystate(26, Ics, Line, Tlen, Action, Alen) ->
    {Action,Alen,Tlen,Ics,Line,26};
yystate(25, [124|Ics], Line, Tlen, _, _) ->
    yystate(59, Ics, Line, Tlen+1, 23, Tlen);
yystate(25, [92|Ics], Line, Tlen, _, _) ->
    yystate(59, Ics, Line, Tlen+1, 23, Tlen);
yystate(25, [58|Ics], Line, Tlen, _, _) ->
    yystate(59, Ics, Line, Tlen+1, 23, Tlen);
yystate(25, [47|Ics], Line, Tlen, _, _) ->
    yystate(59, Ics, Line, Tlen+1, 23, Tlen);
yystate(25, [46|Ics], Line, Tlen, _, _) ->
    yystate(21, Ics, Line, Tlen+1, 23, Tlen);
yystate(25, [33|Ics], Line, Tlen, _, _) ->
    yystate(59, Ics, Line, Tlen+1, 23, Tlen);
yystate(25, [C|Ics], Line, Tlen, _, _) when C >= 35, C =< 39 ->
    yystate(59, Ics, Line, Tlen+1, 23, Tlen);
yystate(25, [C|Ics], Line, Tlen, _, _) when C >= 42, C =< 45 ->
    yystate(59, Ics, Line, Tlen+1, 23, Tlen);
yystate(25, [C|Ics], Line, Tlen, _, _) when C >= 48, C =< 57 ->
    yystate(25, Ics, Line, Tlen+1, 23, Tlen);
yystate(25, [C|Ics], Line, Tlen, _, _) when C >= 60, C =< 90 ->
    yystate(59, Ics, Line, Tlen+1, 23, Tlen);
yystate(25, [C|Ics], Line, Tlen, _, _) when C >= 94, C =< 122 ->
    yystate(59, Ics, Line, Tlen+1, 23, Tlen);
yystate(25, [C|Ics], Line, Tlen, _, _) when C >= 126 ->
    yystate(59, Ics, Line, Tlen+1, 23, Tlen);
yystate(25, Ics, Line, Tlen, _, _) ->
    {23,Tlen,Ics,Line,25};
yystate(24, Ics, Line, Tlen, _, _) ->
    {5,Tlen,Ics,Line};
yystate(23, [124|Ics], Line, Tlen, Action, Alen) ->
    yystate(31, Ics, Line, Tlen+1, Action, Alen);
yystate(23, [92|Ics], Line, Tlen, Action, Alen) ->
    yystate(31, Ics, Line, Tlen+1, Action, Alen);
yystate(23, [58|Ics], Line, Tlen, Action, Alen) ->
    yystate(31, Ics, Line, Tlen+1, Action, Alen);
yystate(23, [47|Ics], Line, Tlen, Action, Alen) ->
    yystate(23, Ics, Line, Tlen+1, Action, Alen);
yystate(23, [33|Ics], Line, Tlen, Action, Alen) ->
    yystate(31, Ics, Line, Tlen+1, Action, Alen);
yystate(23, [C|Ics], Line, Tlen, Action, Alen) when C >= 35, C =< 39 ->
    yystate(31, Ics, Line, Tlen+1, Action, Alen);
yystate(23, [C|Ics], Line, Tlen, Action, Alen) when C >= 42, C =< 46 ->
    yystate(31, Ics, Line, Tlen+1, Action, Alen);
yystate(23, [C|Ics], Line, Tlen, Action, Alen) when C >= 48, C =< 57 ->
    yystate(27, Ics, Line, Tlen+1, Action, Alen);
yystate(23, [C|Ics], Line, Tlen, Action, Alen) when C >= 60, C =< 90 ->
    yystate(31, Ics, Line, Tlen+1, Action, Alen);
yystate(23, [C|Ics], Line, Tlen, Action, Alen) when C >= 94, C =< 122 ->
    yystate(31, Ics, Line, Tlen+1, Action, Alen);
yystate(23, [C|Ics], Line, Tlen, Action, Alen) when C >= 126 ->
    yystate(31, Ics, Line, Tlen+1, Action, Alen);
yystate(23, Ics, Line, Tlen, Action, Alen) ->
    {Action,Alen,Tlen,Ics,Line,23};
yystate(22, [124|Ics], Line, Tlen, Action, Alen) ->
    yystate(26, Ics, Line, Tlen+1, Action, Alen);
yystate(22, [120|Ics], Line, Tlen, Action, Alen) ->
    yystate(62, Ics, Line, Tlen+1, Action, Alen);
yystate(22, [111|Ics], Line, Tlen, Action, Alen) ->
    yystate(60, Ics, Line, Tlen+1, Action, Alen);
yystate(22, [109|Ics], Line, Tlen, Action, Alen) ->
    yystate(52, Ics, Line, Tlen+1, Action, Alen);
yystate(22, [100|Ics], Line, Tlen, Action, Alen) ->
    yystate(44, Ics, Line, Tlen+1, Action, Alen);
yystate(22, [98|Ics], Line, Tlen, Action, Alen) ->
    yystate(36, Ics, Line, Tlen+1, Action, Alen);
yystate(22, [96|Ics], Line, Tlen, Action, Alen) ->
    yystate(46, Ics, Line, Tlen+1, Action, Alen);
yystate(22, [92|Ics], Line, Tlen, Action, Alen) ->
    yystate(50, Ics, Line, Tlen+1, Action, Alen);
yystate(22, [88|Ics], Line, Tlen, Action, Alen) ->
    yystate(62, Ics, Line, Tlen+1, Action, Alen);
yystate(22, [79|Ics], Line, Tlen, Action, Alen) ->
    yystate(60, Ics, Line, Tlen+1, Action, Alen);
yystate(22, [77|Ics], Line, Tlen, Action, Alen) ->
    yystate(52, Ics, Line, Tlen+1, Action, Alen);
yystate(22, [68|Ics], Line, Tlen, Action, Alen) ->
    yystate(44, Ics, Line, Tlen+1, Action, Alen);
yystate(22, [66|Ics], Line, Tlen, Action, Alen) ->
    yystate(36, Ics, Line, Tlen+1, Action, Alen);
yystate(22, [59|Ics], Line, Tlen, Action, Alen) ->
    yystate(24, Ics, Line, Tlen+1, Action, Alen);
yystate(22, [51|Ics], Line, Tlen, Action, Alen) ->
    yystate(12, Ics, Line, Tlen+1, Action, Alen);
yystate(22, [50|Ics], Line, Tlen, Action, Alen) ->
    yystate(8, Ics, Line, Tlen+1, Action, Alen);
yystate(22, [49|Ics], Line, Tlen, Action, Alen) ->
    yystate(0, Ics, Line, Tlen+1, Action, Alen);
yystate(22, [48|Ics], Line, Tlen, Action, Alen) ->
    yystate(3, Ics, Line, Tlen+1, Action, Alen);
yystate(22, [44|Ics], Line, Tlen, Action, Alen) ->
    yystate(7, Ics, Line, Tlen+1, Action, Alen);
yystate(22, [40|Ics], Line, Tlen, Action, Alen) ->
    yystate(15, Ics, Line, Tlen+1, Action, Alen);
yystate(22, [39|Ics], Line, Tlen, Action, Alen) ->
    yystate(19, Ics, Line, Tlen+1, Action, Alen);
yystate(22, [C|Ics], Line, Tlen, Action, Alen) when C >= 52, C =< 57 ->
    yystate(4, Ics, Line, Tlen+1, Action, Alen);
yystate(22, Ics, Line, Tlen, Action, Alen) ->
    {Action,Alen,Tlen,Ics,Line,22};
yystate(21, [124|Ics], Line, Tlen, _, _) ->
    yystate(59, Ics, Line, Tlen+1, 25, Tlen);
yystate(21, [92|Ics], Line, Tlen, _, _) ->
    yystate(59, Ics, Line, Tlen+1, 25, Tlen);
yystate(21, [58|Ics], Line, Tlen, _, _) ->
    yystate(59, Ics, Line, Tlen+1, 25, Tlen);
yystate(21, [33|Ics], Line, Tlen, _, _) ->
    yystate(59, Ics, Line, Tlen+1, 25, Tlen);
yystate(21, [C|Ics], Line, Tlen, _, _) when C >= 35, C =< 39 ->
    yystate(59, Ics, Line, Tlen+1, 25, Tlen);
yystate(21, [C|Ics], Line, Tlen, _, _) when C >= 42, C =< 47 ->
    yystate(59, Ics, Line, Tlen+1, 25, Tlen);
yystate(21, [C|Ics], Line, Tlen, _, _) when C >= 48, C =< 57 ->
    yystate(17, Ics, Line, Tlen+1, 25, Tlen);
yystate(21, [C|Ics], Line, Tlen, _, _) when C >= 60, C =< 90 ->
    yystate(59, Ics, Line, Tlen+1, 25, Tlen);
yystate(21, [C|Ics], Line, Tlen, _, _) when C >= 94, C =< 122 ->
    yystate(59, Ics, Line, Tlen+1, 25, Tlen);
yystate(21, [C|Ics], Line, Tlen, _, _) when C >= 126 ->
    yystate(59, Ics, Line, Tlen+1, 25, Tlen);
yystate(21, Ics, Line, Tlen, _, _) ->
    {25,Tlen,Ics,Line,21};
yystate(20, [C|Ics], Line, Tlen, Action, Alen) when C >= 48, C =< 57 ->
    yystate(16, Ics, Line, Tlen+1, Action, Alen);
yystate(20, [C|Ics], Line, Tlen, Action, Alen) when C >= 65, C =< 90 ->
    yystate(16, Ics, Line, Tlen+1, Action, Alen);
yystate(20, [C|Ics], Line, Tlen, Action, Alen) when C >= 97, C =< 122 ->
    yystate(16, Ics, Line, Tlen+1, Action, Alen);
yystate(20, Ics, Line, Tlen, Action, Alen) ->
    {Action,Alen,Tlen,Ics,Line,20};
yystate(19, [94|Ics], Line, Tlen, Action, Alen) ->
    yystate(31, Ics, Line, Tlen+1, Action, Alen);
yystate(19, [95|Ics], Line, Tlen, Action, Alen) ->
    yystate(31, Ics, Line, Tlen+1, Action, Alen);
yystate(19, [92|Ics], Line, Tlen, Action, Alen) ->
    yystate(31, Ics, Line, Tlen+1, Action, Alen);
yystate(19, [42|Ics], Line, Tlen, Action, Alen) ->
    yystate(31, Ics, Line, Tlen+1, Action, Alen);
yystate(19, [43|Ics], Line, Tlen, Action, Alen) ->
    yystate(31, Ics, Line, Tlen+1, Action, Alen);
yystate(19, [33|Ics], Line, Tlen, Action, Alen) ->
    yystate(31, Ics, Line, Tlen+1, Action, Alen);
yystate(19, [C|Ics], Line, Tlen, Action, Alen) when C >= 36, C =< 38 ->
    yystate(31, Ics, Line, Tlen+1, Action, Alen);
yystate(19, [C|Ics], Line, Tlen, Action, Alen) when C >= 45, C =< 58 ->
    yystate(31, Ics, Line, Tlen+1, Action, Alen);
yystate(19, [C|Ics], Line, Tlen, Action, Alen) when C >= 60, C =< 90 ->
    yystate(31, Ics, Line, Tlen+1, Action, Alen);
yystate(19, [C|Ics], Line, Tlen, Action, Alen) when C >= 97, C =< 122 ->
    yystate(31, Ics, Line, Tlen+1, Action, Alen);
yystate(19, [C|Ics], Line, Tlen, Action, Alen) when C >= 126 ->
    yystate(31, Ics, Line, Tlen+1, Action, Alen);
yystate(19, Ics, Line, Tlen, Action, Alen) ->
    {Action,Alen,Tlen,Ics,Line,19};
yystate(18, Ics, Line, Tlen, _, _) ->
    {8,Tlen,Ics,Line};
yystate(17, [124|Ics], Line, Tlen, _, _) ->
    yystate(59, Ics, Line, Tlen+1, 24, Tlen);
yystate(17, [101|Ics], Line, Tlen, _, _) ->
    yystate(13, Ics, Line, Tlen+1, 24, Tlen);
yystate(17, [92|Ics], Line, Tlen, _, _) ->
    yystate(59, Ics, Line, Tlen+1, 24, Tlen);
yystate(17, [69|Ics], Line, Tlen, _, _) ->
    yystate(13, Ics, Line, Tlen+1, 24, Tlen);
yystate(17, [58|Ics], Line, Tlen, _, _) ->
    yystate(59, Ics, Line, Tlen+1, 24, Tlen);
yystate(17, [33|Ics], Line, Tlen, _, _) ->
    yystate(59, Ics, Line, Tlen+1, 24, Tlen);
yystate(17, [C|Ics], Line, Tlen, _, _) when C >= 35, C =< 39 ->
    yystate(59, Ics, Line, Tlen+1, 24, Tlen);
yystate(17, [C|Ics], Line, Tlen, _, _) when C >= 42, C =< 47 ->
    yystate(59, Ics, Line, Tlen+1, 24, Tlen);
yystate(17, [C|Ics], Line, Tlen, _, _) when C >= 48, C =< 57 ->
    yystate(17, Ics, Line, Tlen+1, 24, Tlen);
yystate(17, [C|Ics], Line, Tlen, _, _) when C >= 60, C =< 68 ->
    yystate(59, Ics, Line, Tlen+1, 24, Tlen);
yystate(17, [C|Ics], Line, Tlen, _, _) when C >= 70, C =< 90 ->
    yystate(59, Ics, Line, Tlen+1, 24, Tlen);
yystate(17, [C|Ics], Line, Tlen, _, _) when C >= 94, C =< 100 ->
    yystate(59, Ics, Line, Tlen+1, 24, Tlen);
yystate(17, [C|Ics], Line, Tlen, _, _) when C >= 102, C =< 122 ->
    yystate(59, Ics, Line, Tlen+1, 24, Tlen);
yystate(17, [C|Ics], Line, Tlen, _, _) when C >= 126 ->
    yystate(59, Ics, Line, Tlen+1, 24, Tlen);
yystate(17, Ics, Line, Tlen, _, _) ->
    {24,Tlen,Ics,Line,17};
yystate(16, [C|Ics], Line, Tlen, _, _) when C >= 48, C =< 57 ->
    yystate(16, Ics, Line, Tlen+1, 22, Tlen);
yystate(16, [C|Ics], Line, Tlen, _, _) when C >= 65, C =< 90 ->
    yystate(16, Ics, Line, Tlen+1, 22, Tlen);
yystate(16, [C|Ics], Line, Tlen, _, _) when C >= 97, C =< 122 ->
    yystate(16, Ics, Line, Tlen+1, 22, Tlen);
yystate(16, Ics, Line, Tlen, _, _) ->
    {22,Tlen,Ics,Line,16};
yystate(15, Ics, Line, Tlen, _, _) ->
    {3,Tlen,Ics,Line};
yystate(14, Ics, Line, Tlen, _, _) ->
    {13,Tlen,Ics,Line};
yystate(13, [124|Ics], Line, Tlen, _, _) ->
    yystate(59, Ics, Line, Tlen+1, 25, Tlen);
yystate(13, [92|Ics], Line, Tlen, _, _) ->
    yystate(59, Ics, Line, Tlen+1, 25, Tlen);
yystate(13, [58|Ics], Line, Tlen, _, _) ->
    yystate(59, Ics, Line, Tlen+1, 25, Tlen);
yystate(13, [46|Ics], Line, Tlen, _, _) ->
    yystate(59, Ics, Line, Tlen+1, 25, Tlen);
yystate(13, [47|Ics], Line, Tlen, _, _) ->
    yystate(59, Ics, Line, Tlen+1, 25, Tlen);
yystate(13, [45|Ics], Line, Tlen, _, _) ->
    yystate(5, Ics, Line, Tlen+1, 25, Tlen);
yystate(13, [44|Ics], Line, Tlen, _, _) ->
    yystate(59, Ics, Line, Tlen+1, 25, Tlen);
yystate(13, [43|Ics], Line, Tlen, _, _) ->
    yystate(5, Ics, Line, Tlen+1, 25, Tlen);
yystate(13, [42|Ics], Line, Tlen, _, _) ->
    yystate(59, Ics, Line, Tlen+1, 25, Tlen);
yystate(13, [33|Ics], Line, Tlen, _, _) ->
    yystate(59, Ics, Line, Tlen+1, 25, Tlen);
yystate(13, [C|Ics], Line, Tlen, _, _) when C >= 35, C =< 39 ->
    yystate(59, Ics, Line, Tlen+1, 25, Tlen);
yystate(13, [C|Ics], Line, Tlen, _, _) when C >= 48, C =< 57 ->
    yystate(9, Ics, Line, Tlen+1, 25, Tlen);
yystate(13, [C|Ics], Line, Tlen, _, _) when C >= 60, C =< 90 ->
    yystate(59, Ics, Line, Tlen+1, 25, Tlen);
yystate(13, [C|Ics], Line, Tlen, _, _) when C >= 94, C =< 122 ->
    yystate(59, Ics, Line, Tlen+1, 25, Tlen);
yystate(13, [C|Ics], Line, Tlen, _, _) when C >= 126 ->
    yystate(59, Ics, Line, Tlen+1, 25, Tlen);
yystate(13, Ics, Line, Tlen, _, _) ->
    {25,Tlen,Ics,Line,13};
yystate(12, [114|Ics], Line, Tlen, Action, Alen) ->
    yystate(20, Ics, Line, Tlen+1, Action, Alen);
yystate(12, [82|Ics], Line, Tlen, Action, Alen) ->
    yystate(20, Ics, Line, Tlen+1, Action, Alen);
yystate(12, [C|Ics], Line, Tlen, Action, Alen) when C >= 48, C =< 54 ->
    yystate(4, Ics, Line, Tlen+1, Action, Alen);
yystate(12, Ics, Line, Tlen, Action, Alen) ->
    {Action,Alen,Tlen,Ics,Line,12};
yystate(11, Ics, Line, Tlen, _, _) ->
    {7,Tlen,Ics,Line};
yystate(10, [124|Ics], Line, Tlen, _, _) ->
    yystate(59, Ics, Line, Tlen+1, 25, Tlen);
yystate(10, [92|Ics], Line, Tlen, _, _) ->
    yystate(59, Ics, Line, Tlen+1, 25, Tlen);
yystate(10, [58|Ics], Line, Tlen, _, _) ->
    yystate(59, Ics, Line, Tlen+1, 25, Tlen);
yystate(10, [33|Ics], Line, Tlen, _, _) ->
    yystate(59, Ics, Line, Tlen+1, 25, Tlen);
yystate(10, [C|Ics], Line, Tlen, _, _) when C >= 35, C =< 39 ->
    yystate(59, Ics, Line, Tlen+1, 25, Tlen);
yystate(10, [C|Ics], Line, Tlen, _, _) when C >= 42, C =< 47 ->
    yystate(59, Ics, Line, Tlen+1, 25, Tlen);
yystate(10, [C|Ics], Line, Tlen, _, _) when C >= 48, C =< 57 ->
    yystate(25, Ics, Line, Tlen+1, 25, Tlen);
yystate(10, [C|Ics], Line, Tlen, _, _) when C >= 60, C =< 90 ->
    yystate(59, Ics, Line, Tlen+1, 25, Tlen);
yystate(10, [C|Ics], Line, Tlen, _, _) when C >= 94, C =< 122 ->
    yystate(59, Ics, Line, Tlen+1, 25, Tlen);
yystate(10, [C|Ics], Line, Tlen, _, _) when C >= 126 ->
    yystate(59, Ics, Line, Tlen+1, 25, Tlen);
yystate(10, Ics, Line, Tlen, _, _) ->
    {25,Tlen,Ics,Line,10};
yystate(9, [124|Ics], Line, Tlen, _, _) ->
    yystate(59, Ics, Line, Tlen+1, 24, Tlen);
yystate(9, [92|Ics], Line, Tlen, _, _) ->
    yystate(59, Ics, Line, Tlen+1, 24, Tlen);
yystate(9, [58|Ics], Line, Tlen, _, _) ->
    yystate(59, Ics, Line, Tlen+1, 24, Tlen);
yystate(9, [33|Ics], Line, Tlen, _, _) ->
    yystate(59, Ics, Line, Tlen+1, 24, Tlen);
yystate(9, [C|Ics], Line, Tlen, _, _) when C >= 35, C =< 39 ->
    yystate(59, Ics, Line, Tlen+1, 24, Tlen);
yystate(9, [C|Ics], Line, Tlen, _, _) when C >= 42, C =< 47 ->
    yystate(59, Ics, Line, Tlen+1, 24, Tlen);
yystate(9, [C|Ics], Line, Tlen, _, _) when C >= 48, C =< 57 ->
    yystate(9, Ics, Line, Tlen+1, 24, Tlen);
yystate(9, [C|Ics], Line, Tlen, _, _) when C >= 60, C =< 90 ->
    yystate(59, Ics, Line, Tlen+1, 24, Tlen);
yystate(9, [C|Ics], Line, Tlen, _, _) when C >= 94, C =< 122 ->
    yystate(59, Ics, Line, Tlen+1, 24, Tlen);
yystate(9, [C|Ics], Line, Tlen, _, _) when C >= 126 ->
    yystate(59, Ics, Line, Tlen+1, 24, Tlen);
yystate(9, Ics, Line, Tlen, _, _) ->
    {24,Tlen,Ics,Line,9};
yystate(8, [114|Ics], Line, Tlen, Action, Alen) ->
    yystate(20, Ics, Line, Tlen+1, Action, Alen);
yystate(8, [82|Ics], Line, Tlen, Action, Alen) ->
    yystate(20, Ics, Line, Tlen+1, Action, Alen);
yystate(8, [C|Ics], Line, Tlen, Action, Alen) when C >= 48, C =< 57 ->
    yystate(4, Ics, Line, Tlen+1, Action, Alen);
yystate(8, Ics, Line, Tlen, Action, Alen) ->
    {Action,Alen,Tlen,Ics,Line,8};
yystate(7, [64|Ics], Line, Tlen, _, _) ->
    yystate(11, Ics, Line, Tlen+1, 6, Tlen);
yystate(7, Ics, Line, Tlen, _, _) ->
    {6,Tlen,Ics,Line,7};
yystate(6, Ics, Line, Tlen, _, _) ->
    {11,Tlen,Ics,Line};
yystate(5, [124|Ics], Line, Tlen, _, _) ->
    yystate(59, Ics, Line, Tlen+1, 25, Tlen);
yystate(5, [92|Ics], Line, Tlen, _, _) ->
    yystate(59, Ics, Line, Tlen+1, 25, Tlen);
yystate(5, [58|Ics], Line, Tlen, _, _) ->
    yystate(59, Ics, Line, Tlen+1, 25, Tlen);
yystate(5, [33|Ics], Line, Tlen, _, _) ->
    yystate(59, Ics, Line, Tlen+1, 25, Tlen);
yystate(5, [C|Ics], Line, Tlen, _, _) when C >= 35, C =< 39 ->
    yystate(59, Ics, Line, Tlen+1, 25, Tlen);
yystate(5, [C|Ics], Line, Tlen, _, _) when C >= 42, C =< 47 ->
    yystate(59, Ics, Line, Tlen+1, 25, Tlen);
yystate(5, [C|Ics], Line, Tlen, _, _) when C >= 48, C =< 57 ->
    yystate(9, Ics, Line, Tlen+1, 25, Tlen);
yystate(5, [C|Ics], Line, Tlen, _, _) when C >= 60, C =< 90 ->
    yystate(59, Ics, Line, Tlen+1, 25, Tlen);
yystate(5, [C|Ics], Line, Tlen, _, _) when C >= 94, C =< 122 ->
    yystate(59, Ics, Line, Tlen+1, 25, Tlen);
yystate(5, [C|Ics], Line, Tlen, _, _) when C >= 126 ->
    yystate(59, Ics, Line, Tlen+1, 25, Tlen);
yystate(5, Ics, Line, Tlen, _, _) ->
    {25,Tlen,Ics,Line,5};
yystate(4, [114|Ics], Line, Tlen, Action, Alen) ->
    yystate(20, Ics, Line, Tlen+1, Action, Alen);
yystate(4, [82|Ics], Line, Tlen, Action, Alen) ->
    yystate(20, Ics, Line, Tlen+1, Action, Alen);
yystate(4, Ics, Line, Tlen, Action, Alen) ->
    {Action,Alen,Tlen,Ics,Line,4};
yystate(3, [C|Ics], Line, Tlen, Action, Alen) when C >= 50, C =< 57 ->
    yystate(4, Ics, Line, Tlen+1, Action, Alen);
yystate(3, Ics, Line, Tlen, Action, Alen) ->
    {Action,Alen,Tlen,Ics,Line,3};
yystate(2, [64|Ics], Line, Tlen, _, _) ->
    yystate(6, Ics, Line, Tlen+1, 10, Tlen);
yystate(2, Ics, Line, Tlen, _, _) ->
    {10,Tlen,Ics,Line,2};
yystate(1, [124|Ics], Line, Tlen, _, _) ->
    yystate(59, Ics, Line, Tlen+1, 12, Tlen);
yystate(1, [92|Ics], Line, Tlen, _, _) ->
    yystate(59, Ics, Line, Tlen+1, 12, Tlen);
yystate(1, [33|Ics], Line, Tlen, _, _) ->
    yystate(59, Ics, Line, Tlen+1, 12, Tlen);
yystate(1, [C|Ics], Line, Tlen, _, _) when C >= 35, C =< 39 ->
    yystate(59, Ics, Line, Tlen+1, 12, Tlen);
yystate(1, [C|Ics], Line, Tlen, _, _) when C >= 42, C =< 58 ->
    yystate(59, Ics, Line, Tlen+1, 12, Tlen);
yystate(1, [C|Ics], Line, Tlen, _, _) when C >= 60, C =< 90 ->
    yystate(59, Ics, Line, Tlen+1, 12, Tlen);
yystate(1, [C|Ics], Line, Tlen, _, _) when C >= 94, C =< 122 ->
    yystate(59, Ics, Line, Tlen+1, 12, Tlen);
yystate(1, [C|Ics], Line, Tlen, _, _) when C >= 126 ->
    yystate(59, Ics, Line, Tlen+1, 12, Tlen);
yystate(1, Ics, Line, Tlen, _, _) ->
    {12,Tlen,Ics,Line,1};
yystate(0, [C|Ics], Line, Tlen, Action, Alen) when C >= 48, C =< 57 ->
    yystate(4, Ics, Line, Tlen+1, Action, Alen);
yystate(0, Ics, Line, Tlen, Action, Alen) ->
    {Action,Alen,Tlen,Ics,Line,0};
yystate(S, Ics, Line, Tlen, Action, Alen) ->
    {Action,Alen,Tlen,Ics,Line,S}.

%% yyaction(Action, TokenLength, TokenChars, TokenLine) ->
%% {token,Token} | {end_token, Token} | skip_token | {error,String}.
%% Generated action function.

yyaction(0, TokenLen, YYtcs, _) ->
    TokenChars = yypre(YYtcs, TokenLen),
    yyaction_0(TokenChars);
yyaction(1, _, _, TokenLine) ->
    yyaction_1(TokenLine);
yyaction(2, _, _, TokenLine) ->
    yyaction_2(TokenLine);
yyaction(3, _, _, TokenLine) ->
    yyaction_3(TokenLine);
yyaction(4, _, _, TokenLine) ->
    yyaction_4(TokenLine);
yyaction(5, _, _, TokenLine) ->
    yyaction_5(TokenLine);
yyaction(6, _, _, TokenLine) ->
    yyaction_6(TokenLine);
yyaction(7, _, _, TokenLine) ->
    yyaction_7(TokenLine);
yyaction(8, _, _, TokenLine) ->
    yyaction_8(TokenLine);
yyaction(9, _, _, TokenLine) ->
    yyaction_9(TokenLine);
yyaction(10, _, _, TokenLine) ->
    yyaction_10(TokenLine);
yyaction(11, _, _, TokenLine) ->
    yyaction_11(TokenLine);
yyaction(12, _, _, TokenLine) ->
    yyaction_12(TokenLine);
yyaction(13, TokenLen, YYtcs, TokenLine) ->
    TokenChars = yypre(YYtcs, TokenLen),
    yyaction_13(TokenChars, TokenLine);
yyaction(14, TokenLen, YYtcs, TokenLine) ->
    TokenChars = yypre(YYtcs, TokenLen),
    yyaction_14(TokenChars, TokenLine);
yyaction(15, TokenLen, YYtcs, TokenLine) ->
    TokenChars = yypre(YYtcs, TokenLen),
    yyaction_15(TokenChars, TokenLen, TokenLine);
yyaction(16, TokenLen, YYtcs, TokenLine) ->
    TokenChars = yypre(YYtcs, TokenLen),
    yyaction_16(TokenChars, TokenLen, TokenLine);
yyaction(17, TokenLen, YYtcs, TokenLine) ->
    TokenChars = yypre(YYtcs, TokenLen),
    yyaction_17(TokenChars, TokenLine);
yyaction(18, TokenLen, YYtcs, TokenLine) ->
    TokenChars = yypre(YYtcs, TokenLen),
    yyaction_18(TokenChars, TokenLine);
yyaction(19, TokenLen, YYtcs, TokenLine) ->
    TokenChars = yypre(YYtcs, TokenLen),
    yyaction_19(TokenChars, TokenLine);
yyaction(20, TokenLen, YYtcs, TokenLine) ->
    TokenChars = yypre(YYtcs, TokenLen),
    yyaction_20(TokenChars, TokenLine);
yyaction(21, TokenLen, YYtcs, TokenLine) ->
    TokenChars = yypre(YYtcs, TokenLen),
    yyaction_21(TokenChars, TokenLine);
yyaction(22, TokenLen, YYtcs, TokenLine) ->
    TokenChars = yypre(YYtcs, TokenLen),
    yyaction_22(TokenChars, TokenLine);
yyaction(23, TokenLen, YYtcs, TokenLine) ->
    TokenChars = yypre(YYtcs, TokenLen),
    yyaction_23(TokenChars, TokenLine);
yyaction(24, TokenLen, YYtcs, TokenLine) ->
    TokenChars = yypre(YYtcs, TokenLen),
    yyaction_24(TokenChars, TokenLine);
yyaction(25, TokenLen, YYtcs, TokenLine) ->
    TokenChars = yypre(YYtcs, TokenLen),
    yyaction_25(TokenChars, TokenLine);
yyaction(26, _, _, _) ->
    yyaction_26();
yyaction(_, _, _, _) -> error.

-compile({inline,yyaction_0/1}).
-file("src/lfe_scan.xrl", 33).
yyaction_0(TokenChars) ->
     block_comment (string : substr (TokenChars, 3)) .

-compile({inline,yyaction_1/1}).
-file("src/lfe_scan.xrl", 35).
yyaction_1(TokenLine) ->
     { token, { '#B(', TokenLine } } .

-compile({inline,yyaction_2/1}).
-file("src/lfe_scan.xrl", 36).
yyaction_2(TokenLine) ->
     { token, { '#M(', TokenLine } } .

-compile({inline,yyaction_3/1}).
-file("src/lfe_scan.xrl", 37).
yyaction_3(TokenLine) ->
     { token, { '#(', TokenLine } } .

-compile({inline,yyaction_4/1}).
-file("src/lfe_scan.xrl", 38).
yyaction_4(TokenLine) ->
     { token, { '#`', TokenLine } } .

-compile({inline,yyaction_5/1}).
-file("src/lfe_scan.xrl", 39).
yyaction_5(TokenLine) ->
     { token, { '#;', TokenLine } } .

-compile({inline,yyaction_6/1}).
-file("src/lfe_scan.xrl", 40).
yyaction_6(TokenLine) ->
     { token, { '#,', TokenLine } } .

-compile({inline,yyaction_7/1}).
-file("src/lfe_scan.xrl", 41).
yyaction_7(TokenLine) ->
     { token, { '#,@', TokenLine } } .

-compile({inline,yyaction_8/1}).
-file("src/lfe_scan.xrl", 42).
yyaction_8(TokenLine) ->
     { token, { '\'', TokenLine } } .

-compile({inline,yyaction_9/1}).
-file("src/lfe_scan.xrl", 43).
yyaction_9(TokenLine) ->
     { token, { '`', TokenLine } } .

-compile({inline,yyaction_10/1}).
-file("src/lfe_scan.xrl", 44).
yyaction_10(TokenLine) ->
     { token, { ',', TokenLine } } .

-compile({inline,yyaction_11/1}).
-file("src/lfe_scan.xrl", 45).
yyaction_11(TokenLine) ->
     { token, { ',@', TokenLine } } .

-compile({inline,yyaction_12/1}).
-file("src/lfe_scan.xrl", 46).
yyaction_12(TokenLine) ->
     { token, { '.', TokenLine } } .

-compile({inline,yyaction_13/2}).
-file("src/lfe_scan.xrl", 47).
yyaction_13(TokenChars, TokenLine) ->
     { token, { list_to_atom (TokenChars), TokenLine } } .

-compile({inline,yyaction_14/2}).
-file("src/lfe_scan.xrl", 49).
yyaction_14(TokenChars, TokenLine) ->
     char_token (string : substr (TokenChars, 3), TokenLine) .

-compile({inline,yyaction_15/3}).
-file("src/lfe_scan.xrl", 53).
yyaction_15(TokenChars, TokenLen, TokenLine) ->
     S = string : substr (TokenChars, 2, TokenLen - 2),
     { token, { string, TokenLine, chars (S) } } .

-compile({inline,yyaction_16/3}).
-file("src/lfe_scan.xrl", 58).
yyaction_16(TokenChars, TokenLen, TokenLine) ->
     S = string : substr (TokenChars, 2, TokenLen - 2),
     symbol_token (chars (S), TokenLine) .

-compile({inline,yyaction_17/2}).
-file("src/lfe_scan.xrl", 63).
yyaction_17(TokenChars, TokenLine) ->
     FunStr = string : substr (TokenChars, 3),
     { token, { '#\'', TokenLine, FunStr } } .

-compile({inline,yyaction_18/2}).
-file("src/lfe_scan.xrl", 66).
yyaction_18(TokenChars, TokenLine) ->
     base_token (string : substr (TokenChars, 3), 2, TokenLine) .

-compile({inline,yyaction_19/2}).
-file("src/lfe_scan.xrl", 67).
yyaction_19(TokenChars, TokenLine) ->
     base_token (string : substr (TokenChars, 3), 8, TokenLine) .

-compile({inline,yyaction_20/2}).
-file("src/lfe_scan.xrl", 68).
yyaction_20(TokenChars, TokenLine) ->
     base_token (string : substr (TokenChars, 3), 10, TokenLine) .

-compile({inline,yyaction_21/2}).
-file("src/lfe_scan.xrl", 69).
yyaction_21(TokenChars, TokenLine) ->
     base_token (string : substr (TokenChars, 3), 16, TokenLine) .

-compile({inline,yyaction_22/2}).
-file("src/lfe_scan.xrl", 72).
yyaction_22(TokenChars, TokenLine) ->
     { Base, [_ | Ds ] } = base1 (string : substr (TokenChars, 2), 10, 0),
     base_token (Ds, Base, TokenLine) .

-compile({inline,yyaction_23/2}).
-file("src/lfe_scan.xrl", 77).
yyaction_23(TokenChars, TokenLine) ->
     case catch { ok, list_to_integer (TokenChars) } of
     { ok, I } -> { token, { number, TokenLine, I } } ;
     _ -> { error, "illegal integer" }
     end .

-compile({inline,yyaction_24/2}).
-file("src/lfe_scan.xrl", 82).
yyaction_24(TokenChars, TokenLine) ->
     case catch { ok, list_to_float (TokenChars) } of
     { ok, F } -> { token, { number, TokenLine, F } } ;
     _ -> { error, "illegal float" }
     end .

-compile({inline,yyaction_25/2}).
-file("src/lfe_scan.xrl", 87).
yyaction_25(TokenChars, TokenLine) ->
     symbol_token (TokenChars, TokenLine) .

-compile({inline,yyaction_26/0}).
-file("src/lfe_scan.xrl", 88).
yyaction_26() ->
     skip_token .

-file("/usr/local/lib/erlang/lib/parsetools-2.1.1/include/leexinc.hrl", 290).
